@@ -3,10 +3,10 @@ package Config::Simple::Conf;
 
 use strict;
 # Version number - cvs automagically updated.
-our $VERSION = $1 if('$Revision: 1.2 $' =~ /: ([\d\.]+)/);
+our $VERSION = $1 if('$Revision: 1.3 $' =~ /: ([\d\.]+)/);
 
 # Revision - cvs automagically updated
-our $REVISION = '$Id: Conf.pm,v 1.2 2016/04/15 19:50:25 cfaber Exp $';
+our $REVISION = '$Id: Conf.pm,v 1.3 2016/04/20 04:17:58 cfaber Exp $';
 
 # Ruckus Global Version Number
 
@@ -257,7 +257,6 @@ sub _cliargs {
 			$v =~ s/^\s+//g;
 			$v =~ s/\s+$//g;
 
-print "KV: $k $v\n";
 			if(exists $conf->{$k} && $conf->{$k} ne "\x18"){
 				if(ref($conf->{$k}) eq 'ARRAY'){
 					push @{ $conf->{$k} }, $v;
@@ -317,38 +316,6 @@ print "KV: $k $v\n";
 }
 
 
-# Combine results
-sub _stage1 {
-	my ($conf, $cfg) = @_;
-	if(ref($cfg) =~ /^(HASH|Config::Simple::Conf)$/){
-		for my $sec (keys %{ $cfg }){
-			for my $key (keys %{ $cfg->{$sec} }){
-				if(ref($conf->{$sec}->{$key}) eq 'ARRAY'){
-					if(ref($cfg->{$sec}->{$key}) eq 'ARRAY'){
-						push @{ $conf->{$sec}->{$key} }, @{ $cfg->{$sec}->{$key} };
-					} elsif($cfg->{$sec}->{$key}){
-						push @{ $conf->{$sec}->{$key} }, $cfg->{$sec}->{$key};
-					}
-				} else {
-					if(ref($cfg->{$sec}->{$key}) eq 'ARRAY'){
-						push @{ $cfg->{$sec}->{$key} }, $conf->{$sec}->{$key} if $conf->{$sec}->{$key};
-						$conf->{$sec}->{$key} = $cfg->{$sec}->{$key};
-					} else {
-						if($conf->{$sec}->{$key} && $cfg->{$sec}->{$key}){
-							push my @tmp, ($conf->{$sec}->{$key}, $cfg->{$sec}->{$key});
-							$conf->{$sec}->{$key} = \@tmp;
-						} elsif($cfg->{$sec}->{$key}){
-							$conf->{$sec}->{$key} = $cfg->{$sec}->{$key};
-						}
-					}
-				}
-			}
-		}
-	}
-
-	return $conf;
-}
-
 # This routine reprocesses the configuration hash, and replaces any [section:name], or [name] variables with their setting.
 sub _stage2 {
 	my ($conf) = @_;
@@ -361,7 +328,7 @@ sub _stage2 {
 				if(ref($conf->{$sec}->{$key}) eq 'ARRAY'){
 					for(my $i = 0; $i < @{ $conf->{$sec}->{$key} }; $i++){
 						if($conf->{$sec}->{$key}->[$i] =~ /\[([^:]+)\:([^\]]+)]/){
-							my ($aa, $ab) = ($1, $2);
+							my ($aa, $ab) = (lc $1, lc $2);
 
 							if(ref($conf->{$aa}->{$ab}) eq 'ARRAY'){
 								&_die("ERROR: the embedded key [$aa:$ab] in section [$sec] must be unique: " . join("; ", @{ $conf->{$aa}->{$ab} }));
@@ -370,7 +337,7 @@ sub _stage2 {
 								$try++;
 							}
 						} elsif($conf->{$sec}->{$key}->[$i] =~ /\[([^\]]+)]/){
-							my $aa = $1;
+							my $aa = lc $1;
 
 							if(ref($conf->{global}->{$aa}) eq 'ARRAY'){
 								&_die("ERROR: the embedded global key [$aa] in section [$sec] must be unique: " . join("; ", @{ $conf->{global}->{$aa} }));
@@ -382,7 +349,7 @@ sub _stage2 {
 					}
 				} else {
 					if(!ref($conf->{$sec}->{$key}) && $conf->{$sec}->{$key} =~ /\[([^:]+):([^\]]+)\]/){
-						my ($aa, $ab) = ($1, $2);
+						my ($aa, $ab) = (lc $1, lc $2);
 
 						if(ref($conf->{$aa}->{$ab}) eq 'ARRAY'){
 							&_die("ERROR: the embedded key [$aa:$ab] in section [$sec] must be unique: " . join("; ", @{ $conf->{$aa}->{$ab} }));
@@ -391,7 +358,7 @@ sub _stage2 {
 							$try++;
 						}
 					} elsif(!ref($conf->{$sec}->{$key}) && $conf->{$sec}->{$key} =~ /\[([^\]]+)\]/){
-						my $aa = $1;
+						my $aa = lc $1;
 
 						if(ref($conf->{global}->{$aa}) eq 'ARRAY'){
 							&_die("ERROR: the embedded key [$aa] in section [$sec] must be unique: " . join("; ", @{ $conf->{global}->{$aa} }));
